==> deepin-music_3.1.8.3+ds.orig.tar.gz: deepin-music-3.1.8.3+ds/CHANGELOG.md <==
<a name="3.1.8.3"></a>
## 3.1.8.3 (2018-05-14)


#### Bug Fixes

*   update mpris status ([87934402](https://github.com/linuxdeepin/deepin-music/commit/8793440212a8e5677462d8feaf4d2c4b51aedc3a))
*   dock not support group ([03de3cdb](https://github.com/linuxdeepin/deepin-music/commit/03de3cdb5cb5da89ddc87981eca99653a45ff6bd))
*   fav status disappear ([2feb298c](https://github.com/linuxdeepin/deepin-music/commit/2feb298cae2ab898d0552e4e60441f344d010262))

#### Features

*   trash file with dde-file-manager dbus in flatpak ([91f664a1](https://github.com/linuxdeepin/deepin-music/commit/91f664a1b8e027fcf3627a63f19581970bff8ffc))



<a name="3.1.8.1"></a>
## 3.1.8.1 (2018-03-12)


#### Bug Fixes

*   add missing depends gstreamer1.0-fluendo-mp3 ([5065d227](https://github.com/linuxdeepin/deepin-music/commit/5065d227292d882926d5cfbd28ae1c31cbcbb6f9))
*   shortcut not work ([145883f9](https://github.com/linuxdeepin/deepin-music/commit/145883f93a3f3d462ade584bfbeda69f5154029e))



<a name="3.1.8"></a>
## 3.1.8 (2018-03-06)


#### Features

*   support sliber animation ([5088cd98](https://github.com/linuxdeepin/deepin-music/commit/5088cd9848fbda3ecaafa0a6823b398de6937d53))
*   auto resize progress ([b4869ba9](https://github.com/linuxdeepin/deepin-music/commit/b4869ba99dff452a8c1cf90e0b508e58601e5a43))
*   hide custom sort from menu ([ddc4b609](https://github.com/linuxdeepin/deepin-music/commit/ddc4b60934f2692eb9e3870f59f2726bd8bc1a05))
*   keep sound hint when clicked ([d1a7c9ad](https://github.com/linuxdeepin/deepin-music/commit/d1a7c9adacd8ce1f23c6c58a84d1ecc7c15198fa))
*   sync progress on close ([3a0ff320](https://github.com/linuxdeepin/deepin-music/commit/3a0ff320a014e81b5eedec65c3a32b359fcd6f1c))
*   use DThemeManger ([f3e9659e](https://github.com/linuxdeepin/deepin-music/commit/f3e9659e8c4997c16314e9239eb6dcdefeb14612))
*   add manual id ([d21100f9](https://github.com/linuxdeepin/deepin-music/commit/d21100f941a4e11d3ff5b3fda4e0e44e9d303784))
*   add VERSION configure option to define app version. ([ae4c1fed](https://github.com/linuxdeepin/deepin-music/commit/ae4c1fed06ae0cd8ea1c681ed022cd2b333d0540))

#### Bug Fixes

*   hide dock icon when close to minitray ([18459921](https://github.com/linuxdeepin/deepin-music/commit/184599216faa3c9945cf0f1ed0792f9ab9c76b82))
*   try hide/show to make windowFlags change effect ([7ce74ffd](https://github.com/linuxdeepin/deepin-music/commit/7ce74ffd6b14527805d8c68d2b9035e50b987e69))
*   network changed reset cover data ([2fb24abb](https://github.com/linuxdeepin/deepin-music/commit/2fb24abb333d32d230d402708e142064cae43306))
*   qss not work for CloseConfirmDialog ([76c10c2c](https://github.com/linuxdeepin/deepin-music/commit/76c10c2ce04511fb51069a4e7537b31a9b627067))
*   add missing depends libqt5sql5-sqlite libqt5multimedia5-plugins ([c338d86d](https://github.com/linuxdeepin/deepin-music/commit/c338d86df98236362b77d34f9a87a60812d46c9b))
*   add missing depends ([972ea100](https://github.com/linuxdeepin/deepin-music/commit/972ea10011f361faa32ef6ccc105b0bd36f5dd66))
*   add depends gstreamer1.0-plugins-ugly ([b0a28734](https://github.com/linuxdeepin/deepin-music/commit/b0a287348638831e7c0d4afd728f5663068c90bc))
*   Adapt lintian ([fe242955](https://github.com/linuxdeepin/deepin-music/commit/fe2429559e7c95e17e6c42f9eb8b38a89723744c))
*   work for qss repaint in hidpi ([49f5b1ba](https://github.com/linuxdeepin/deepin-music/commit/49f5b1ba3c6023b564cf721e8d8d87203c48b285))



<a name="3.1.7.2"></a>
## 3.1.7.2 (2017-11-23)


#### Features

*   change default shortcut ([62b2b2e1](https://github.com/linuxdeepin/deepin-music/commit/62b2b2e16a333dd9227f8e4c9e4673a28af884d2))



<a name="3.1.7.1"></a>
## 3.1.7.1 (2017-11-23)


#### Bug Fixes

*   showNormal not work ([bb22dc99](https://github.com/linuxdeepin/deepin-music/commit/bb22dc999db0c6e3d72b5062b5c061c4a45bba35))
*   crash when selectNext on qt 5.9 ([bed9d856](https://github.com/linuxdeepin/deepin-music/commit/bed9d85682d9edf7a20d78801c6ec4b4cd076ad9))



<a name="3.1.7"></a>
## 3.1.7 (2017-11-23)


#### Bug Fixes

*   fix hidpi playing state ([84783418](https://github.com/linuxdeepin/deepin-music/commit/847834182e7c699a3fa267e40017eee9362e1d18))
*   fix lyric text cut ([1dbf4dc2](https://github.com/linuxdeepin/deepin-music/commit/1dbf4dc27657ae0c71a6a4c6ca628a4ec7793381))
*   move qmediaplayer to main thread ([3ce0ca3c](https://github.com/linuxdeepin/deepin-music/commit/3ce0ca3cc855ef4d2c549e6007f0f00c558f6f1d))
*   fix dialog style ([cfc0db93](https://github.com/linuxdeepin/deepin-music/commit/cfc0db93060cb89770ba9335ff9a5bead30c8989))
*   use deviceRatio in musicitemdelegate ([f3a65085](https://github.com/linuxdeepin/deepin-music/commit/f3a6508583585c620b5bc13e60ecbcb8e92f2e33))
*   enable drag progress bar ([22f8916e](https://github.com/linuxdeepin/deepin-music/commit/22f8916e95ab232399d05aef467f00255228161f))
*   fix border pos ([6fa9cc9e](https://github.com/linuxdeepin/deepin-music/commit/6fa9cc9e4e510f1bc7ecee8a70f90b5fac9eff92))
*   set dialog flag error ([ef200472](https://github.com/linuxdeepin/deepin-music/commit/ef200472746005b230bc5bc01d51cfcbf530031f))
*   change footer bar cover mouse cursor ([a4837dce](https://github.com/linuxdeepin/deepin-music/commit/a4837dce12ffd8495feeec9d9b534ab4c8ee65af))
*   fix libdmusic install path ([2d86199a](https://github.com/linuxdeepin/deepin-music/commit/2d86199a688bb738f1981aeca08cd503d6eb46d3))
*   make dropdown show full text on ru locale ([fcc58c97](https://github.com/linuxdeepin/deepin-music/commit/fcc58c97acd642409ae58f69d899bc9628b319ca))

#### Features

*   stop next after continue error count >= 5 ([e6127596](https://github.com/linuxdeepin/deepin-music/commit/e6127596456e17f3712245521864669cee839793))
*   call dbus trash ([b5d6fcb4](https://github.com/linuxdeepin/deepin-music/commit/b5d6fcb40b4b8b991d4ffaf505b6e7a062572ed9))
*   extern footer progress ([3459625e](https://github.com/linuxdeepin/deepin-music/commit/3459625efaec034844fb3dbdeadba4fc6b8ee43c))
*   all use svg ([a942c308](https://github.com/linuxdeepin/deepin-music/commit/a942c30887a32242c07c39997aac1e7ea5e59302))
*   use dbus call filemanager ([e276e636](https://github.com/linuxdeepin/deepin-music/commit/e276e63639ed928a8e2519b8ff9985ba68c9803f))
*   remove dtk2 workaround ([0eb1ee32](https://github.com/linuxdeepin/deepin-music/commit/0eb1ee3234a635496dd9abbc6c6a2dd60253e10a))
*   use dtk DWaterProgress ([6109ffee](https://github.com/linuxdeepin/deepin-music/commit/6109ffeefa5894d8a5b8f9aaba35364f56ca8e43))
* **hidpi:**  add hidpi support ([107e5987](https://github.com/linuxdeepin/deepin-music/commit/107e59879f0959ce7364a5833a150feec3d2479c))

==> deepin-music_3.1.14+ds.orig.tar.gz: deepin-music-3.1.14+ds/CHANGELOG.md <==
<a name="3.1.14"></a>
## 3.1.14 (2019-01-25)


#### Bug Fixes

*   avoid using dpkg-parsechangelog ([d730e277](https://github.com/linuxdeepin/deepin-music/commit/d730e2778b925a0f4323d9a224321bc66572106c))



<a name="3.1.13"></a>
## 3.1.13 (2018-12-27)


#### Bug Fixes

*   last opened path check ([5def1504](https://github.com/linuxdeepin/deepin-music/commit/5def15043cc3355771ae2e091e801a1a925d039b))



<a name="3.1.12"></a>
## 3.1.12 (2018-12-21)


#### Bug Fixes

*   multiple duplicated items when open via associated file ([d4bf361c](https://github.com/linuxdeepin/deepin-music/commit/d4bf361cfe9364233d8afa20aef5da6d90f185e2))



<a name="3.1.11"></a>
## 3.1.11 (2018-11-27)




<a name="3.1.10"></a>
## 3.1.10 (2018-11-26)


#### Bug Fixes

*   avoid set a empty path to QFileDialog ([c6c46e6a](https://github.com/linuxdeepin/deepin-music/commit/c6c46e6a6eb78225874582adba247087989b8be2))

#### Features

*   support X-Deepin-Vendor ([9731274c](https://github.com/linuxdeepin/deepin-music/commit/9731274cf48febb6cad1b0568524fd3635f637f7))
*   support the recent file spec. ([b4c128f6](https://github.com/linuxdeepin/deepin-music/commit/b4c128f60a25343f4443231be69ab670d1c05e6f))



<a name="3.1.9"></a>
## 3.1.9 (2018-11-08)


#### Bug Fixes

*   pull tx failed ([0457b68a](https://github.com/linuxdeepin/deepin-music/commit/0457b68ac8fe40e3c976c9097f49ac3c66068c1f))



<a name="3.1.8.6"></a>
## 3.1.8.6 (2018-11-07)


#### Bug Fixes

*   write datebase error ([4fa4ef03](https://github.com/linuxdeepin/deepin-music/commit/4fa4ef03ba64599486d8a16ecda72a351bc3765e))



<a name="3.1.8.5"></a>
## 3.1.8.5 (2018-10-26)


#### Bug Fixes

*   extrend close button area ([07149b51](https://github.com/linuxdeepin/deepin-music/commit/07149b51a27354cce215586884155e7c8d9cf590))

#### Features

*   disable keyboardSearch ([46c2fecb](https://github.com/linuxdeepin/deepin-music/commit/46c2fecb7b7b2f3b68930241499a95a361ad6344))



<a name="3.1.8.4"></a>
## 3.1.8.4 (2018-08-12)


#### Features

*   refactor ([4c70ffdb](https://github.com/linuxdeepin/deepin-music/commit/4c70ffdb51296201e7be025cf73f4182d6851747))



<a name="3.1.8.3"></a>
## 3.1.8.3 (2018-05-14)


#### Bug Fixes

*   update mpris status ([87934402](https://github.com/linuxdeepin/deepin-music/commit/8793440212a8e5677462d8feaf4d2c4b51aedc3a))
*   dock not support group ([03de3cdb](https://github.com/linuxdeepin/deepin-music/commit/03de3cdb5cb5da89ddc87981eca99653a45ff6bd))
*   fav status disappear ([2feb298c](https://github.com/linuxdeepin/deepin-music/commit/2feb298cae2ab898d0552e4e60441f344d010262))

#### Features

*   trash file with dde-file-manager dbus in flatpak ([91f664a1](https://github.com/linuxdeepin/deepin-music/commit/91f664a1b8e027fcf3627a63f19581970bff8ffc))



<a name="3.1.8.1"></a>
## 3.1.8.1 (2018-03-12)


#### Bug Fixes

*   add missing depends gstreamer1.0-fluendo-mp3 ([5065d227](https://github.com/linuxdeepin/deepin-music/commit/5065d227292d882926d5cfbd28ae1c31cbcbb6f9))
*   shortcut not work ([145883f9](https://github.com/linuxdeepin/deepin-music/commit/145883f93a3f3d462ade584bfbeda69f5154029e))



<a name="3.1.8"></a>
## 3.1.8 (2018-03-06)


#### Features

*   support sliber animation ([5088cd98](https://github.com/linuxdeepin/deepin-music/commit/5088cd9848fbda3ecaafa0a6823b398de6937d53))
*   auto resize progress ([b4869ba9](https://github.com/linuxdeepin/deepin-music/commit/b4869ba99dff452a8c1cf90e0b508e58601e5a43))
*   hide custom sort from menu ([ddc4b609](https://github.com/linuxdeepin/deepin-music/commit/ddc4b60934f2692eb9e3870f59f2726bd8bc1a05))
*   keep sound hint when clicked ([d1a7c9ad](https://github.com/linuxdeepin/deepin-music/commit/d1a7c9adacd8ce1f23c6c58a84d1ecc7c15198fa))
*   sync progress on close ([3a0ff320](https://github.com/linuxdeepin/deepin-music/commit/3a0ff320a014e81b5eedec65c3a32b359fcd6f1c))
*   use DThemeManger ([f3e9659e](https://github.com/linuxdeepin/deepin-music/commit/f3e9659e8c4997c16314e9239eb6dcdefeb14612))
*   add manual id ([d21100f9](https://github.com/linuxdeepin/deepin-music/commit/d21100f941a4e11d3ff5b3fda4e0e44e9d303784))
*   add VERSION configure option to define app version. ([ae4c1fed](https://github.com/linuxdeepin/deepin-music/commit/ae4c1fed06ae0cd8ea1c681ed022cd2b333d0540))

#### Bug Fixes

*   hide dock icon when close to minitray ([18459921](https://github.com/linuxdeepin/deepin-music/commit/184599216faa3c9945cf0f1ed0792f9ab9c76b82))
*   try hide/show to make windowFlags change effect ([7ce74ffd](https://github.com/linuxdeepin/deepin-music/commit/7ce74ffd6b14527805d8c68d2b9035e50b987e69))
*   network changed reset cover data ([2fb24abb](https://github.com/linuxdeepin/deepin-music/commit/2fb24abb333d32d230d402708e142064cae43306))
*   qss not work for CloseConfirmDialog ([76c10c2c](https://github.com/linuxdeepin/deepin-music/commit/76c10c2ce04511fb51069a4e7537b31a9b627067))
*   add missing depends libqt5sql5-sqlite libqt5multimedia5-plugins ([c338d86d](https://github.com/linuxdeepin/deepin-music/commit/c338d86df98236362b77d34f9a87a60812d46c9b))
*   add missing depends ([972ea100](https://github.com/linuxdeepin/deepin-music/commit/972ea10011f361faa32ef6ccc105b0bd36f5dd66))
*   add depends gstreamer1.0-plugins-ugly ([b0a28734](https://github.com/linuxdeepin/deepin-music/commit/b0a287348638831e7c0d4afd728f5663068c90bc))
*   Adapt lintian ([fe242955](https://github.com/linuxdeepin/deepin-music/commit/fe2429559e7c95e17e6c42f9eb8b38a89723744c))
*   work for qss repaint in hidpi ([49f5b1ba](https://github.com/linuxdeepin/deepin-music/commit/49f5b1ba3c6023b564cf721e8d8d87203c48b285))



<a name="3.1.7.2"></a>
## 3.1.7.2 (2017-11-23)


#### Features

*   change default shortcut ([62b2b2e1](https://github.com/linuxdeepin/deepin-music/commit/62b2b2e16a333dd9227f8e4c9e4673a28af884d2))



<a name="3.1.7.1"></a>
## 3.1.7.1 (2017-11-23)


#### Bug Fixes

*   showNormal not work ([bb22dc99](https://github.com/linuxdeepin/deepin-music/commit/bb22dc999db0c6e3d72b5062b5c061c4a45bba35))
*   crash when selectNext on qt 5.9 ([bed9d856](https://github.com/linuxdeepin/deepin-music/commit/bed9d85682d9edf7a20d78801c6ec4b4cd076ad9))



<a name="3.1.7"></a>
## 3.1.7 (2017-11-23)


#### Bug Fixes

*   fix hidpi playing state ([84783418](https://github.com/linuxdeepin/deepin-music/commit/847834182e7c699a3fa267e40017eee9362e1d18))
*   fix lyric text cut ([1dbf4dc2](https://github.com/linuxdeepin/deepin-music/commit/1dbf4dc27657ae0c71a6a4c6ca628a4ec7793381))
*   move qmediaplayer to main thread ([3ce0ca3c](https://github.com/linuxdeepin/deepin-music/commit/3ce0ca3cc855ef4d2c549e6007f0f00c558f6f1d))
*   fix dialog style ([cfc0db93](https://github.com/linuxdeepin/deepin-music/commit/cfc0db93060cb89770ba9335ff9a5bead30c8989))
*   use deviceRatio in musicitemdelegate ([f3a65085](https://github.com/linuxdeepin/deepin-music/commit/f3a6508583585c620b5bc13e60ecbcb8e92f2e33))
*   enable drag progress bar ([22f8916e](https://github.com/linuxdeepin/deepin-music/commit/22f8916e95ab232399d05aef467f00255228161f))
*   fix border pos ([6fa9cc9e](https://github.com/linuxdeepin/deepin-music/commit/6fa9cc9e4e510f1bc7ecee8a70f90b5fac9eff92))
*   set dialog flag error ([ef200472](https://github.com/linuxdeepin/deepin-music/commit/ef200472746005b230bc5bc01d51cfcbf530031f))
*   change footer bar cover mouse cursor ([a4837dce](https://github.com/linuxdeepin/deepin-music/commit/a4837dce12ffd8495feeec9d9b534ab4c8ee65af))
*   fix libdmusic install path ([2d86199a](https://github.com/linuxdeepin/deepin-music/commit/2d86199a688bb738f1981aeca08cd503d6eb46d3))
*   make dropdown show full text on ru locale ([fcc58c97](https://github.com/linuxdeepin/deepin-music/commit/fcc58c97acd642409ae58f69d899bc9628b319ca))

#### Features

*   stop next after continue error count >= 5 ([e6127596](https://github.com/linuxdeepin/deepin-music/commit/e6127596456e17f3712245521864669cee839793))
*   call dbus trash ([b5d6fcb4](https://github.com/linuxdeepin/deepin-music/commit/b5d6fcb40b4b8b991d4ffaf505b6e7a062572ed9))
*   extern footer progress ([3459625e](https://github.com/linuxdeepin/deepin-music/commit/3459625efaec034844fb3dbdeadba4fc6b8ee43c))
*   all use svg ([a942c308](https://github.com/linuxdeepin/deepin-music/commit/a942c30887a32242c07c39997aac1e7ea5e59302))
*   use dbus call filemanager ([e276e636](https://github.com/linuxdeepin/deepin-music/commit/e276e63639ed928a8e2519b8ff9985ba68c9803f))
*   remove dtk2 workaround ([0eb1ee32](https://github.com/linuxdeepin/deepin-music/commit/0eb1ee3234a635496dd9abbc6c6a2dd60253e10a))
*   use dtk DWaterProgress ([6109ffee](https://github.com/linuxdeepin/deepin-music/commit/6109ffeefa5894d8a5b8f9aaba35364f56ca8e43))
* **hidpi:**  add hidpi support ([107e5987](https://github.com/linuxdeepin/deepin-music/commit/107e59879f0959ce7364a5833a150feec3d2479c))
